diff --git a/tempest/cmd/cleanup_service.py b/tempest/cmd/cleanup_service.py
index 9e86b489a8..8d2cfdcc08 100644
--- a/tempest/cmd/cleanup_service.py
+++ b/tempest/cmd/cleanup_service.py
@@ -661,7 +661,7 @@ class NetworkSecGroupService(NetworkService):
 
         if self.is_preserve:
             secgroups = self._filter_by_conf_networks(secgroups)
-        LOG.debug("List count, %s securtiy_groups" % len(secgroups))
+        LOG.debug("List count, %s security_groups" % len(secgroups))
         return secgroups
 
     def delete(self):
diff --git a/tempest/tests/cmd/test_workspace.py b/tempest/tests/cmd/test_workspace.py
index c4bd7b2ba0..2639d93086 100644
--- a/tempest/tests/cmd/test_workspace.py
+++ b/tempest/tests/cmd/test_workspace.py
@@ -41,8 +41,8 @@ class TestTempestWorkspace(TestTempestWorkspaceBase):
                                    stderr=subprocess.PIPE)
         stdout, stderr = process.communicate()
         return_code = process.returncode
-        msg = ("%s failled with:\nstdout: %s\nstderr: %s" % (' '.join(cmd),
-                                                             stdout, stderr))
+        msg = ("%s failed with:\nstdout: %s\nstderr: %s" % (' '.join(cmd),
+               stdout, stderr))
         self.assertEqual(return_code, expected, msg)
 
     def test_run_workspace_list(self):
diff --git a/tempest/cmd/run.py b/tempest/cmd/run.py
index b4b7ebba88..e78f6b08df 100644
--- a/tempest/cmd/run.py
+++ b/tempest/cmd/run.py
@@ -70,7 +70,7 @@ class TempestRun(command.Command):
 
     def take_action(self, parsed_args):
         self._set_env()
         # Local exceution mode
         if os.path.isfile('.testr.conf'):
             # If you're running in local execution mode and there is not a
             # testrepository dir create one
@@ -80,7 +80,7 @@ class TempestRun(command.Command):
             if returncode:
                 sys.exit(returncode)
         else:
-            print("No .testr.conf file was found for local exceution")
+            print("No .testr.conf file was found for local execution")
             sys.exit(2)
 
         regex = self._build_regex(parsed_args)
@@ -70,7 +70,7 @@ class TempestRun(command.Command):
     def take_action(self, parsed_args):
         self._set_env()
-        # Local exceution mode
+        # Local execution mode
         if os.path.isfile('.testr.conf'):
             # If you're running in local execution mode and there is not a